WebImplementation class

A placeholder implementation for web platform when compiled for non-web environments.

This class throws UnsupportedError or UnimplementedError for all methods, since web functionality is only available on web platforms.

Implemented types

Constructors

WebImplementation({int maxLimit = 1, MediaType mediaType = MediaType.image})
Creates a WebImplementation instance with maxLimit and mediaType.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxLimit → int
The maximum number of files allowed for selection.
final
mediaType → MediaType
The type of media to be picked.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compressFile({required String inputPath}) → Future<String?>
Not implemented. Throws UnimplementedError.
override
getDoc({required int limit, required MediaType mediaType}) → Future<File?>
Not implemented. Throws UnimplementedError.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickMultipleImages() → Future<List<String>?>
Unsupported on non-web platforms. Throws UnsupportedError.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited